[−][src]Crate mun_syntax
Syntax Tree Library used throughout Mun.
This crate is heavily inspired by Rust Analyzers ra_syntax and ra_parser crates.
Properties: - easy and fast incremental re-parsing - graceful handling of errors - full-fidelity representation (any text can be precisely represented as a syntax tree)
Re-exports
pub use crate::ast::AstNode; |
Modules
| ast |
Macros
| T | |
| token_set |
Structs
| AstPtr | Like |
| Parse |
|
| SmolStr | A |
| SourceFile | |
| SyntaxError | |
| SyntaxNodePtr | A pointer to a syntax node inside a file. It can be used to remember a specific node across reparses of the same file. |
| SyntaxTreeBuilder | |
| TextRange | A range in the text, represented as a pair of |
| TextUnit | An offset into text.
Offset is represented as |
| Token | A token of Mun source |
Enums
| Direction | |
| SyntaxErrorKind | |
| SyntaxKind | The kind of syntax node, e.g. |
Functions
| tokenize | Break a string up into its component tokens |
Type Definitions
| SyntaxElement | |
| SyntaxNode | |
| SyntaxToken |